package com.lagou.controller;

import com.lagou.domain.Course;
import com.lagou.domain.CourseVO;
import com.lagou.domain.ResponseResult;
import com.lagou.service.CourseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/course")
public class CourseController {

    @Autowired
    private CourseService courseService;

    /**
     * 查询课程信息
     * &
     * 条件查询
     * @param courseVO
     * @return
     */
    @RequestMapping("/findCourseByCondition")
    public ResponseResult findCourseByCondition(@RequestBody CourseVO courseVO) {

        List<Course> courseList = courseService.findCourseByCondition(courseVO);
        ResponseResult result = new ResponseResult(true, 200, "响应成功", courseList);

        return result;
    }

    /**
     * 图片上传接口
     * @param file
     * @param request
     * @return
     */
    @RequestMapping("/courseUpload")
    public ResponseResult fileUpload(@RequestParam("file")MultipartFile file, HttpServletRequest request) {

        try {
            // 1.非空校验
            if (file.isEmpty()) {
                throw new RuntimeException();
            }

            // 2.获取项目根目录
            // D:\apache-tomcat-8.5.56\webapps\ssm_web\
            String realPath = request.getServletContext().getRealPath("/");
            // D:\apache-tomcat-8.5.56\webapps\
            String webappsPath = realPath.substring(0, realPath.indexOf("ssm_web"));

            // 3.获取源文件名
            // lagou.jpg
            String fileName = file.getOriginalFilename();

            // 4.新文件名
            // 122343242.jpg
            String newFileName = System.currentTimeMillis() + fileName.substring(fileName.lastIndexOf("."));

            // 5.创建文件
            // "D:\apache-tomcat-8.5.56\webapps\ upload\"
            String uploadPath = webappsPath + "upload\\";
            // "D:\apache-tomcat-8.5.56\webapps\ upload\122343242.jpg"
            File filePath = new File(uploadPath, newFileName);

            // 如果目录不存在创建
            if (!filePath.getParentFile().exists()) {
                filePath.getParentFile().mkdirs();
                System.out.println("创建目录：" + filePath);
            }

            // 上传文件
            file.transferTo(filePath);

            // 6.将文件名和文件路径返回
            Map<String, String> map = new HashMap<>();
            map.put("fileName", newFileName);
            map.put("filePath", "http://localhost:8080/upload/" + newFileName);

            ResponseResult result = new ResponseResult(true, 200, "图片上传成功", map);

            return result;

        } catch (IOException e) {

            e.printStackTrace();
            return null;
        }
    }

    /**
     * 新增和更新
     *  课程和讲师信息
     * @param courseVO
     * @return
     * @throws InvocationTargetException
     * @throws IllegalAccessException
     */
    @RequestMapping("/saveOrUpdateCourse")
    public ResponseResult saveOrUpdateCourse(@RequestBody CourseVO courseVO) throws InvocationTargetException, IllegalAccessException {

        if (courseVO.getId() == null) {
            // 调用service
            courseService.saveCourseOrTeacher(courseVO);
            ResponseResult responseResult = new ResponseResult(true, 200, "保存课程信息成功", null);
            return responseResult;
        } else {
            courseService.updateCourseOrTeacher(courseVO);
            ResponseResult responseResult = new ResponseResult(true, 200, "更新课程信息成功", null);
            return responseResult;
        }
    }

    /**
     * 根据id查询具体的课程信息及讲师信息
     *      回显课程信息
     * @param id
     * @return
     */
    @RequestMapping("/findCourseById")
    public ResponseResult findCourseById(Integer id) {
        CourseVO courseVO = courseService.findCourseById(id);

        ResponseResult responseResult = new ResponseResult(true, 200, "根据Id查询课程信息成功", courseVO);
        return responseResult;
    }

    /**
     * 更新课程状态
     * @param id
     * @param status
     * @return
     */
    @RequestMapping("/updateCourseStatus")
    public ResponseResult updateCourseStatus(@RequestParam int id, @RequestParam int status) {

        try {
            courseService.updateCourseStatus(id, status);

            // 响应数据
            Map<String, Integer> map = new HashMap<>();
            map.put("status", status);

            ResponseResult responseResult = new ResponseResult(true, 200, "课程状态更新成功", map);

            return responseResult;

        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
}
