package com.lagou.controller;

import com.github.pagehelper.PageInfo;
import com.lagou.domain.PromotionAd;
import com.lagou.domain.PromotionAdVO;
import com.lagou.domain.ResponseResult;
import com.lagou.service.PromotionAdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

@RestController
@RequestMapping("/PromotionAd")
public class PromotionAdController {

    @Autowired
    private PromotionAdService promotionAdService;

    /**
     * 广告分页查询
     * @param promotionAdVO
     * @return
     */
    @RequestMapping("/findAllPromotionAdByPage")
    public ResponseResult findAllAdByPage(PromotionAdVO promotionAdVO) {

        PageInfo<PromotionAd> allPromotionAdByPage = promotionAdService.findAllPromotionAdByPage(promotionAdVO);

        return new ResponseResult(true, 200, "广告分页查询成功", allPromotionAdByPage);
    }

    /**
     * 图片上传接口
     * @param file
     * @param request
     * @return
     */
    @RequestMapping("/PromotionAdUpload")
    public ResponseResult fileUpload(@RequestParam("file") MultipartFile file, HttpServletRequest request) {

        try {
            // 1.非空校验
            if (file.isEmpty()) {
                throw new RuntimeException();
            }

            // 2.获取项目根目录
            // D:\apache-tomcat-8.5.56\webapps\ssm_web\
            String realPath = request.getServletContext().getRealPath("/");
            // D:\apache-tomcat-8.5.56\webapps\
            String webappsPath = realPath.substring(0, realPath.indexOf("ssm_web"));

            // 3.获取源文件名
            // lagou.jpg
            String fileName = file.getOriginalFilename();

            // 4.新文件名
            // 122343242.jpg
            String newFileName = System.currentTimeMillis() + fileName.substring(fileName.lastIndexOf("."));

            // 5.创建文件
            // "D:\apache-tomcat-8.5.56\webapps\ upload\"
            String uploadPath = webappsPath + "upload\\";
            // "D:\apache-tomcat-8.5.56\webapps\ upload\122343242.jpg"
            File filePath = new File(uploadPath, newFileName);

            // 如果目录不存在创建
            if (!filePath.getParentFile().exists()) {
                filePath.getParentFile().mkdirs();
                System.out.println("创建目录：" + filePath);
            }

            // 上传文件
            file.transferTo(filePath);

            // 6.将文件名和文件路径返回
            Map<String, String> map = new HashMap<>();
            map.put("fileName", newFileName);
            map.put("filePath", "http://localhost:8080/upload/" + newFileName);

            ResponseResult result = new ResponseResult(true, 200, "图片上传成功", map);

            return result;

        } catch (IOException e) {

            e.printStackTrace();
            return null;
        }
    }

    /**
     * 新增   &
     * 修改广告位信息
     * @param promotionAd
     * @return
     */
    @RequestMapping("/saveOrUpdatePromotionAd")
    public ResponseResult saveOrUpdatePromotionAd(@RequestBody PromotionAd promotionAd) {

        if (promotionAd.getId() == null) {
            // 新增
            promotionAdService.savePromotionAd(promotionAd);
            return new ResponseResult(true, 200, "新增广告成功", null);
        } else {
            promotionAdService.updatePromotionAd(promotionAd);
            return new ResponseResult(true, 200, "更新广告成功", null);
        }
    }

    /**
     * 广告动态上下线
     * @param id
     * @param status
     * @return
     */
    @RequestMapping("/updatePromotionAdStatus")
    public ResponseResult updatePromotionAdStatus(Integer id, Integer status) {

        promotionAdService.updatePromotionAdStatus(id, status);

        Map<String, Integer> map = new HashMap<>();
        map.put("status:", status);

        return new ResponseResult(true, 200, "广告动态上下线成功", map);
    }
}
