package com.lagou.controller;

import com.lagou.domain.Menu;
import com.lagou.domain.ResponseResult;
import com.lagou.domain.Role;
import com.lagou.domain.RoleMenuVO;
import com.lagou.service.MenuService;
import com.lagou.service.RoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/role")
public class RoleController {

    @Autowired
    private RoleService roleService;

    @Autowired
    private MenuService menuService;

    /**
     * 查询所有角色（条件）
     * @param role
     * @return
     */
    @RequestMapping("/findAllRole")
    public ResponseResult findAllROle(@RequestBody Role role) {

        List<Role> allRole = roleService.findAllRole(role);

        return new ResponseResult(true, 200, "查找所有角色成功", allRole);
    }

    /**
     * 添加 & 修改角色
     * @param role
     * @return
     */
    @RequestMapping("/saveOrUpdateRole")
    public ResponseResult saveOrUpdateRole(@RequestBody Role role) {

        if (role.getId() == null) {
            // 新增
            roleService.saveRole(role);
            return new ResponseResult(true, 200, "新增角色成功", null);
        } else {
            roleService.updateRole(role);
            return new ResponseResult(true, 200, "修改角色成功", null);
        }
    }

    /**
     * 查询父子级菜单
     * @return
     */
    @RequestMapping("/findAllMenu")
    public ResponseResult findSubMenuListByPid() {

        // -1表示查询父级菜单
        List<Menu> menuList = menuService.findSubMenuListByPid(-1);

        // 响应数据
        Map<String, Object> map = new HashMap<>();
        map.put("parentMenuList", menuList);

        return new ResponseResult(true, 200, "查询所有父子级菜单成功", map);
    }

    /**
     * 根据角色id查询关联的菜单信息id
     * @param roleId
     * @return
     */
    @RequestMapping("/findMenuByRoleId")
    public ResponseResult findMenuByRoleId(Integer roleId) {

        List<Integer> menuByRoleId = roleService.findMenuByRoleId(roleId);

        return new ResponseResult(true, 200, "查询角色关联的菜单信息", menuByRoleId);
    }

    /**
     * 为角色分配菜单
     * @param roleMenuVO
     * @return
     */
    @RequestMapping("/RoleContextMenu")
    public ResponseResult RoleContextMenu(@RequestBody RoleMenuVO roleMenuVO) {

        roleService.roleContextMenu(roleMenuVO);

        return new ResponseResult(true, 200, "角色分配菜单成功", null);
    }

    /**
     * 删除角色
     * @param id
     * @return
     */
    @RequestMapping("/deleteRole")
    public ResponseResult deleteRole(Integer id) {

        roleService.deleteRole(id);
        return new ResponseResult(true, 200, "删除角色成功", null);
    }
}
